/* LayoutPanelWithPopup.java
 *
 * Jim McBeath, July 18, 1998
 */

package jimmc.roots;

import jimmc.treepar.LayoutPanel;

import java.awt.AWTEvent;
import java.awt.Component;
import java.awt.event.MouseEvent;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.PopupMenu;

/** A LayoutPanel with an associated PopupMenu.
 * The container for the LayoutPanel must also call add(popupMenu).
 */
public class LayoutPanelWithPopup extends LayoutPanel {
	/** The popup menu to attach to this text area. */
	PopupMenu popupMenu;

	/** Create the panel. */
	public LayoutPanelWithPopup(PopupMenu p) {
		super(null);
		popupMenu = p;
		enableEvents(AWTEvent.MOUSE_EVENT_MASK);
	}

	/** Process a mouse event to put up our popup menu. */
	public void processMouseEvent(MouseEvent e) {
		if (e.isPopupTrigger()) {
			showPopupMenu(popupMenu,
				e.getComponent(), e.getX(), e.getY());
		}
		super.processMouseEvent(e);
	}

	/** Show our popup menu at a specified point. */
	protected void showPopupMenu(PopupMenu p, Component c, int x, int y) {
		p.show(c, x, y);
	}

	/** Set our font to a fixed-width font. */
	public void setFixedFont() {
		Font f = getFont();
		if (!f.getFamily().equals("monospaced")) {
			Font ff = new Font(
				"monospaced",f.getStyle(),f.getSize());
			setFont(ff);
		}
	}

	/** TBD - need a method that take (x,y) and returns the line of
	 * text around that point, along with the character offset of
	 * the point within the string.
	 */
}

/* end */
