/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, January 12, 1997
 */

package jimmc.roots;

import java.io.*;

/** LineInputStream is a generic line-mode input stream.
 */

public class LineInputStream extends DataInputStream {
	int lineNumber;

	/** Create a new LineInputStream from the specified stream. */
	public LineInputStream(InputStream in) {
		super(in);
		lineNumber = 1;	/* assume we are at the beginning */
	}
	/** Get the line number of the line to be returned on the next call
	 * to readCountedLine.
	 * @return the line number in the file; the first line is line 1
	 */
	public int getLineNumber() {
		return lineNumber;
	}

	/** Read one line of text.
	 * @return the line of text without the newline; null on EOF
	 */
	public String readCountedLine() {
		lineNumber++;
		String s;
		try {
			s = super.readLine();
		} catch (IOException e) {
			/* TBD - error message? */
			return null;
		}
		if (s==null)
			return null;
		if (s.endsWith("\n"))
			return s.substring(0,s.length()-1);
		return s;
	}
}

/* end */
