/* PatternMatch.java
 *
 * Jim McBeath, July 6, 1998
 */

package jimmc.roots;

public class PatternMatch {
	/** Default pattern match. Calls glob. */
	public static boolean stringMatches(String s, String pattern) {
		return glob(s,pattern);
	}

	/** Pattern match using sh-style globbing with ? and * characters. */
	public static boolean glob(String str, String pattern) {
		if (str==null)
			return false;	/* null string never matches. */

		int sx=0;
		for (int px=0; px<pattern.length(); px++) {
			char p = pattern.charAt(px);
			switch (p) {
			case '*':	/* match any zero or more chars */
				/* skip over multiple *'s in a row in order
				 * to avoid terrible performance if
				 * extras are not removed.
				 */
				px++;	/* skip over initial * */
				while (px<pattern.length() &&
				       pattern.charAt(px)=='*')
					px++;
				/* Look at tail part of pattern after '*'
				 * and see if it matches any tail part of
				 * the string str.
				 */
				pattern = pattern.substring(px);
				do {
					if (glob(str.substring(sx),pattern))
						return true;
							/* found a match */
				} while (++sx<=str.length());
				return false;	/* can't match rest of string */
			case '?':	/* match any one character */
				if (++sx>=str.length())
					return false;	/* no chars left in s */
				continue;
			/* TBD - implement [] notation */
			/* TBD - implement \ notation to match meta chars */
			default:
				/* Normal character.  If the pattern character
				 * is lower case, it will match either upper
				 * or lower case in the string; if the pattern
				 * character is upper case, it will only match
				 * upper case in the string.
				 */
				if (sx>=str.length())
					return false;	/* no char there */
				char s = str.charAt(sx++);
				if (s==p || (Character.isLowerCase(p) &&
					     Character.isUpperCase(s) &&
					     Character.toLowerCase(s)==p))
					continue;	/* this char matched */
				return false;	/* match fails at this char */
			}
		}
		if (sx<str.length())
			return false;	/* unmatched chars left in str */
		return true;		/* match */
	}

	/** A main method for testing. */
	public static void main(String[] args) {
		boolean t = stringMatches(args[0],args[1]);
		System.out.println(t);
	}
}

/* end */
