/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, January 12, 1997
 */

package jimmc.roots;

import java.io.*;

/** RootsAddress is an address for a person or union.
 */

public class RootsAddress extends RootsRecord {
	String refString;
	RootsRecord ref;	/* what this is an address of */
	String address;		/* The complete address */
	String phone;		/* Telephone number */

	public RootsAddress(RootsBase base) {
		super(base);
	}

	public static RootsAddress ParseNcvLines(RootsBase base,String lines[]){
		RootsAddress r = new RootsAddress(base);
		int n = 0;
		while (n<lines.length) {
			Ncv nv = new Ncv(lines,n);
			n += nv.numLines;
			r.addNcv(nv);
		}
		return r;
	}
	/* Returns true if we recognized the name and added the value */
	protected boolean addNcv(Ncv nv) {
		if (super.addNcv(nv))
			return true;
		else if (nv.name.equals("WHO"))
			refString = nv.value;
		else if (nv.name.equals("ADDR"))
			address = nv.value;
		else if (nv.name.equals("PHONE"))
			phone = nv.value;
		else
			return false;	/* not recognized */
		return true;		/* OK */
	}

	/* Fix up the links in a record that point to another record */
	protected void link() {
		RootsRecord r;
		RootsRecord ra[];
		super.link();
		if ((r=base.findRecord(refString))!=null)
			ref = r;
	}
	/** Print out the type of an address record */
	public String formatNcvType() {
		return("T:A");
	}
	/** Print out the body of an address record */
	public void formatNcvBody(StringBuffer sb) {
		formatNcvItem(sb,"WHO",refString);
		formatNcvItem(sb,"ADDR",address);
		formatNcvItem(sb,"PHONE",phone);
		super.formatNcvBody(sb);
	}
	public String formatOneLine(PrintOptions po) {
		return "ADDR:"+key+"(TBD)";
	}

	public RootsRecord[] findReference(String what) {
		if (what==null)
			return null;
		if (what.equals("who")||what.equals("ref")) {
			if (ref==null)
				return null;
			return ref.asArray();
		}
		return super.findReference(what);
	}
	public void println(String s) {
		base.println(s);
	}
}

/* end */
