/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, February 11, 1997
 */

package jimmc.roots;

import java.util.StringTokenizer;

class RootsEvent {
	String date;	/* as read from the input file */
	int year;	/* no offset: 1900 is 1900 */
	int month;	/* 1 to 12 */
	int day;	/* 1 to 31 */
	int precision;	/* one of the following: */
	    static final int EXACT = 0;
	    static final int BEFORE = 1;
	    static final int AFTER = 2;
	    static final int ABOUT = 3;
	String place;
	static private final String monthNames[] = {
		"Jan","Feb","Mar","Apr","May","Jun",
		"Jul","Aug","Sep","Oct","Nov","Dec" };

	/** Given a RootsEvent with the date string already filled in,
	 * parse that date string and fill in the year/month/day/precision
	 * fields.
	 * @return true if all parsed OK, false if not.
	 */
	public boolean dateToParts() {
		year = 0;
		month = 0;
		day = 0;
		precision = 0;
		if (date==null || date.equals(""))
			return true;	/* no date */
		StringTokenizer st = new StringTokenizer(date," ,-/");
		if (!st.hasMoreTokens())
			return true;	/* nothing to parse */
		String s = st.nextToken();
		boolean needToken = false;
		if (s.equalsIgnoreCase("ABT")) {
			precision = ABOUT;
			needToken = true;
		} else if (s.equalsIgnoreCase("ca.")) {	/* circa */
			precision = ABOUT;
			needToken = true;
		} else if (s.equalsIgnoreCase("ca")) {	/* circa */
			precision = ABOUT;
			needToken = true;
		} else if (s.equalsIgnoreCase("BEF")) {
			precision = BEFORE;
			needToken = true;
		} else if (s.equalsIgnoreCase("pre")) {
			precision = BEFORE;
			needToken = true;
		} else if (s.equalsIgnoreCase("AFT")) {
			precision = AFTER;
			needToken = true;
		} else if (s.equalsIgnoreCase("post")) {
			precision = AFTER;
			needToken = true;
		}
		if (needToken) {
			if (!st.hasMoreTokens())
				return false;	/* precision, but no date! */
			s = st.nextToken();
			needToken = false;
		}
		if (s.endsWith("?") && precision==ABOUT)
			s = s.substring(0,s.length()-1);
		try {
			day = Integer.parseInt(s);
			if (day>31) {	/* assume just the year specified */
				year = day;
				day = 0;
				if (!st.hasMoreTokens())
					return true;
				return false;
				   /* more stuff we don't know about */
			}
			needToken = true;
		} catch (NumberFormatException e) {}	/* ignore error */
		if (needToken) {
			if (!st.hasMoreTokens())
				return true;
			s = st.nextToken();
			needToken = false;
		}
		for (int i=0; i<12; i++) {
			if (s.equalsIgnoreCase(monthNames[i])) {
				month = i+1;
				needToken = true;
				break;
			}
		}
		if (needToken) {
			if (!st.hasMoreTokens())
				return true;
			s = st.nextToken();
			needToken = false;
		}
		try {
			year = Integer.parseInt(s);
			needToken = true;
		} catch (NumberFormatException e) {}	/* ignore error */
		if (!needToken)
			return false;	/* saw something we didn't recognize */
		if (!st.hasMoreTokens())
			return true;
		if (st.nextToken().equals("?") && !st.hasMoreTokens() &&
						    precision==ABOUT)
			return true;	/* OK */
		return false;	/* more stuff we don't know about */
	}

	/** Give a RootsEvent with the date pieces filled in, generate the
	 * string into the date field.
	 */
	public void dateFromParts() {
		if (year==0 && month==0 && day==0) {
			date = "";	/* no date specified */
			return;
		}
		StringBuffer sb = new StringBuffer();
		switch (precision) {
		case EXACT:
			break;	/* no prefix required */
		case BEFORE:
			sb.append("BEF ");
			break;
		case AFTER:
			sb.append("AFT ");
			break;
		case ABOUT:
			sb.append("ABT ");
			break;
		default:
			sb.append("UNK ");
			break;
		}
		if (day>0)
			sb.append(day).append(" ");
		if (month>=1 && month<=12)
			sb.append(monthNames[month-1]).append(" ");
		if (year>0)
			sb.append(year);
		date = sb.toString();
	}
}

/* end */
