/* ScrolledTextWithPopup.java
 *
 * Jim McBeath, June 10, 1998
 */

package jimmc.roots;

import javax.swing.JTextArea;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.PopupMenu;

/** A ScrolledPane containing a JTextArea with a popup menu.
 */
public class ScrolledTextWithPopup extends ScrolledText
			implements TextPopupListener {
	/** Create the ScrolledText. */
	public ScrolledTextWithPopup(int width, int height) {
		super(width,height);
	}

	/** Create the text area with the popup. */
	protected JTextArea createTextArea() {
		TextPopup outputTextPopup = createTextPopup();
		add(outputTextPopup);
		JTextArea a = new JTextAreaWithPopup(outputTextPopup) {
			public Dimension getPreferredSize() {
				setFixedFont();
				return super.getPreferredSize();
			}
			protected void showPopupMenu(PopupMenu p, Component c,
						int x, int y) {
				TextPopup tp = (TextPopup)p;
				tp.setRecord(this,x,y);
				super.showPopupMenu(p,c,x,y);
			}
		};
		return a;
	}
	
	/** Create the TextPopup menu.
	 * Subclass can override in order to create a subclass of TextPopup.
	 */
	protected TextPopup createTextPopup() {
		return new TextPopup(this);
	}

	/** Process the select command from the popup.
	 * Subclass should override.
	 */
	public void processSelect(String key) {
		/* do nothing. */
	}

	/** Process the selection-remove command from the popup.
	 * Subclass should override.
	 */
	public void processRemove(String key) {
		/* do nothing. */
	}
}

/* end */
