/* JsTimestampField.java
 *
 * Jim McBeath, November 3, 2001
 */

package jimmc.swing;

import java.sql.Timestamp;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.Date;

/** A text editing field that accepts only Timestamp data.
 */
public class JsTimestampField extends JsTextField {
	/** Our parsing format for dates. */
	protected SimpleDateFormat dateFormat;

	/** Parsing format for timestamps. */
	protected SimpleDateFormat timestampFormat;

	/** Create a Timestamp field. */
	public JsTimestampField(int width) {
		super(width);
		dateFormat = new SimpleDateFormat("MMM dd, yyyy");
		dateFormat.setLenient(true);
		timestampFormat = new SimpleDateFormat("MMM dd, yyyy HH:mm:ss");
		timestampFormat.setLenient(true);
			//TBD - use resources to set these formats
	}

    //The EditField interface
	/** Set our value. */
	public void setValue(Object value) {
		if (value==null) {
			setText("");
			return;
		}
		if (value instanceof Timestamp)
			setText(timestampFormat.format((Timestamp)value));
		else if (value instanceof Date)
			setText(dateFormat.format((Date)value));
		else
			setText(value.toString());
	}

	/** Get our value. */
	public Object getValue() {
		String s = getText();
		if (s==null || s.equals(""))
			return null;	//no value specified

		//Try parsing it as a full timestamp
		ParsePosition pos = new ParsePosition(0);
		Object v = timestampFormat.parse(s,pos);
		if (v instanceof Date) {
			return new Timestamp(((Date)v).getTime());
				//convert from Date to Timestamp
		}
		if (v!=null)
			return v;

		//Try parsing it as a date
		pos = new ParsePosition(0);
		v = dateFormat.parse(s,pos);
		if (v!=null)
			return v;

		//We have a non-null string, but didn't parse out
		//a timestamp or date, so throw an exception
		throw new NumberFormatException(s);
	}
    //End EditField interface
}

/* end */
