/* Track.java
 *
 * Jim McBeath, July 11, 1998
 */

package jimmc.treepar;

import java.util.Vector;

/** Track represents one routing track within a routing channel.
 */
public class Track {
	/** Our row. */
	protected Row row;
	/** Our track number within the row. */
	protected int trackNum;
	/** The nets in this track. */
	protected Vector netsVector;
	/** Our position (S coordinate) */
	protected int position;

	/** Create a new track. */
	public Track(Row row, int trackNum) {
		this.row = row;
		this.trackNum = trackNum;
		netsVector = new Vector();
	}

	/** Set our S coordinate. */
	protected void setS(int position) {
		this.position = position;
	}

	/** Add a net to this track. */
	protected void addNet(Net net) {
		netsVector.addElement(net);
	}

	/** If the specified span is in use, return the angle of the net
	 * which blocks that span, or return -1 if the span is available.
	 */
	protected int used(int min, int max) {
		int trackSpace = row.layout.trackSpace;
		for (int n=0; n<netsVector.size(); n++) {
			Net net = (Net)netsVector.elementAt(n);
			if (min>=net.maxR+trackSpace)
				continue;
			if (max<=net.minR-trackSpace)
				continue;
			return net.angle;	/* this net is in the way */
		}
		return -1;	/* available */
	}
}

/* end */
