/* StringUtil.java
 *
 * Jim McBeath, October 17, 2001
 */

package jimmc.util;

import java.util.StringTokenizer;
import java.util.Vector;

/** Utility methods for use with strings. */
public class StringUtil {
	/** Split up a string into an array of strings on a separator char. */
	public static String[] toArray(String s, char sep) {
		return toArray(s,sep,false);
	}

	/** Split up a string into an array of strings.
	 * @param s The string to split.
	 * @param sep The separator character on which to split.
	 * @param ignoreEmpty If true, treat multiple separators as
	 *        a single separator, and ignore blank entries between
	 *        separators.
	 * @return The separated strings.
	 */
	public static String[] toArray(String s, char sep, boolean ignoreEmpty){
		if (s==null)
			return null;
		Vector v = new Vector();
		int len = s.length();
		if (len==0)
			return new String[0];
		int p=0;
		while (true) {	//exit loop via break when no more sep chars
			int x = s.indexOf(sep,p);
			if (x<0)
				break;
			if (!ignoreEmpty || p<x)
				v.addElement(s.substring(p,x));
			p = x+1;
		}
		if (!ignoreEmpty || p<s.length())
			v.addElement(s.substring(p));
		String[] ss = new String[v.size()];
		v.copyInto(ss);
		return ss;
	}
	
	/** Given an array, convert it to a single string. */
	public static String toString(Object[] aa, char sep) {
		return toString(aa,String.valueOf(sep));
	}

	/** Given an array, convert it to a single string. */
	public static String toString(Object[] aa, String sep) {
		if (aa==null)
			return null;
		StringBuffer sb = new StringBuffer();
		for (int i=0; i<aa.length; i++) {
			if (i>0)
				sb.append(sep);
			sb.append(aa[i]);
		}
		return sb.toString();
	}

	/** Given a string, return the initials, i.e. a string consisting
	 * of the first non-blank character of the string plus the first
	 * non-blank character after each blank.
	 */
	public static String getInitials(String name) {
		name = name.trim();
		StringTokenizer st = new StringTokenizer(name);
		StringBuffer sb = new StringBuffer();
		while (st.hasMoreTokens()) {
			String token = st.nextToken();
			sb.append(token.charAt(0));
		}
		return sb.toString();
	}

	/** Given a string, return the upper-case initials,
	 * i.e. a string consisting of the first non-blank character of
	 * each space-separated token in the string which is an upper-case
	 * character.
	 */
	public static String getUpperCaseInitials(String name) {
		name = name.trim();
		StringTokenizer st = new StringTokenizer(name);
		StringBuffer sb = new StringBuffer();
		while (st.hasMoreTokens()) {
			String token = st.nextToken();
			char ch = token.charAt(0);
			if (Character.isUpperCase(ch))
				sb.append(ch);
		}
		return sb.toString();
	}
}

/* end */
